==> mutual_credit-5.0.5.tar.gz: mutual_credit/modules/clearingcentral/src/Controller/Endpoint.php <==
<?php

/**
 * @file
 * Contains \Drupal\mcapi_cc\Endpoint.
 * Handles incoming requests from ClearingCentral
 */

namespace Drupal\mcapi_cc\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Utility\UrlHelper;
use Symfony\Component\HttpFoundation\Response;
use \Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use \Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for requests from ClearingCentral
 */
class Endpoint extends ControllerBase implements ContainerInjectionInterface {

  private $clearingCentral;

  function __construct($clearing_central) {
    $this->clearingCentral = $clearing_central;
  }

  static function create(ContainerInterface $container) {
    return new static(
      $container->get('mcapi_cc.clearing_central')
    );
  }

  /**
   * Receive the message as server B from clearing central.
   *
   * Validate and save the transaction, and return it with a response code.
   *
   * @return array transaction || int
   *   The transaction in the remote format or an error code
   */
  function receiver()  {
    $post = $_REQUEST;
    $required = ['txid', 'description', 'seller_nid', 'buyer_nid'];
    foreach ($required as $f) {
      if (!isset($post[$f])) {
        $this->getLogger('clearingcentral')->error("Missing field $f in Clearing central input.");
        return new Response('', 400);
      }
    }
    $this->clearingCentral->receive($post);
    $this->getLogger('clearingcentral')->notice(print_r($post, 1));
    $status_code = $post['response'] == CEN_SUCCESS ? 201 : 200;
    $response = new Response(UrlHelper::buildQuery($post), $status_code);


    $response->send();
    exit;
  }

}

==> mutual_credit-5.0.6.tar.gz: mutual_credit/modules/clearingcentral/src/Controller/Endpoint.php <==
<?php

/**
 * @file
 * Contains \Drupal\mcapi_cc\Endpoint.
 * Handles incoming requests from ClearingCentral
 */

namespace Drupal\mcapi_cc\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Utility\UrlHelper;
use Symfony\Component\HttpFoundation\Response;
use \Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use \Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for requests from ClearingCentral
 */
class Endpoint extends ControllerBase implements ContainerInjectionInterface {

  private $clearingCentral;

  function __construct($clearing_central) {
    $this->clearingCentral = $clearing_central;
  }

  static function create(ContainerInterface $container) {
    return new static(
      $container->get('mcapi_cc.clearing_central')
    );
  }

  /**
   * Receive the message as server B from clearing central.
   *
   * Validate and save the transaction, and return it with a response code.
   *
   * @return array transaction || int
   *   The transaction in the remote format or an error code
   */
  function receiver()  {
    $post = $_REQUEST;
    $required = ['txid', 'description', 'seller_nid', 'buyer_nid'];
    foreach ($required as $f) {
      if (!isset($post[$f])) {
        $this->getLogger('clearingcentral')->error("Missing field @fieldname in Clearing central input.", ['@fieldname' => $f]);
        return new Response('', 400);
      }
    }
    $this->getLogger('clearingcentral')->notice(print_r($post, 1));
    $this->clearingCentral->receive($post);
    $status_code = $post['response'] == CEN_SUCCESS ? 201 : 200;
    $response = new Response(UrlHelper::buildQuery($post), $status_code);


    $response->send();
    exit;
  }

}
